<?php
/** Pälzisch (Pälzisch)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Als-Holder
 * @author SPS
 * @author Xqt
 */

$fallback = 'de';

$messages = array(
# User preference toggles
'tog-showtoolbar' => "Werkzaich zum Bearwaide zaische (dodezu braucht's JavaScript)",

'underline-always'  => 'Immer',
'underline-never'   => 'Garnet',
'underline-default' => 'Des nemme, was em Broweser gsaacht hoscht.',

# Dates
'january'       => 'Jänner',
'february'      => 'Fewwer',
'march'         => 'März',
'april'         => 'Abril',
'may_long'      => 'Mai',
'june'          => 'Juni',
'july'          => 'Juli',
'august'        => 'Auguscht',
'september'     => 'Sebdember',
'october'       => 'Ogdower',
'november'      => 'November',
'december'      => 'Dezember',
'january-gen'   => 'Jänner',
'february-gen'  => 'Fewwer',
'march-gen'     => 'März',
'april-gen'     => 'Abril',
'may-gen'       => 'Mai',
'june-gen'      => 'Juni',
'july-gen'      => 'Juli',
'august-gen'    => 'Auguscht',
'september-gen' => 'Sebdember',
'october-gen'   => 'Ogdower',
'november-gen'  => 'November',
'december-gen'  => 'Dezember',
'jan'           => 'Jän',
'feb'           => 'Few',
'mar'           => 'Mär',
'apr'           => 'Abr',
'may'           => 'Mai',
'jun'           => 'Jun',
'jul'           => 'Jul',
'aug'           => 'Aug',
'sep'           => 'Seb',
'oct'           => 'Ogd',
'nov'           => 'Nov',
'dec'           => 'Dez',

# Categories related messages
'pagecategories'         => '{{PLURAL:$1|Kadegorie|Kadegorie}}',
'category_header'        => 'Saide in de Kadegorie „$1“',
'subcategories'          => 'Unnerkadegorie',
'category-media-header'  => 'Medie in de Kadegorie „$1“',
'hidden-categories'      => '{{PLURAL:$1|Versteckelte Kadegorie|Versteckelte Kadegorie}}',
'category-subcat-count'  => '{{PLURAL:$2|Die Kategorie hot die Unnerkategorie:|{{PLURAL:$1|Die Unnerkategori isch eni vun insgsamt $2 Unnerkategorie in derre Kategorie:|S werre $1 vun insgsamt $2 Unnerkategorie in derre Kategorie aagezeicht:}}}}',
'category-article-count' => "{{PLURAL:$2|In derre Kadegorie hot's numme die Said.|Die {{PLURAL:$1|Said|$1 Saide}} gebbt's in derre Kadegorie, vun insgsamt $2.}}",
'listingcontinuesabbrev' => '(Forts.)',

'about'      => 'Iwwer',
'newwindow'  => '(werd im e naie Fenschter uffgmacht)',
'cancel'     => 'Abbreche',
'mytalk'     => 'Gebabbel mit dir',
'navigation' => 'Navigation',

# Cologne Blue skin
'qbfind'      => 'Finne',
'qbedit'      => 'Bearwaide',
'qbmyoptions' => 'Mai Saide',

# Vector skin
'vector-action-move'    => 'Verschiewe',
'vector-namespace-user' => 'Benutzersaid',
'vector-view-edit'      => 'Bearwaide',

'errorpagetitle'   => 'Fehler',
'returnto'         => 'Zrick zu $1.',
'tagline'          => 'Vun {{SITENAME}}',
'help'             => 'Hilfe',
'search'           => 'Suche',
'searchbutton'     => 'Suche',
'go'               => 'Adiggel',
'searcharticle'    => 'Suche',
'history'          => 'Gschicht vun de Said',
'history_short'    => 'Versione',
'printableversion' => 'Druck-Aasicht',
'permalink'        => 'Permanentlink',
'print'            => 'Ausdrugge',
'edit'             => 'Bearwaide',
'create'           => 'Aaleche',
'editthispage'     => 'Die Said bearwaide',
'delete'           => 'Lesche',
'undelete_short'   => '{{PLURAL:$1|ä Ännerung|$1 Ännerunge}} widderherschdelle',
'protect'          => 'schitze',
'protect_change'   => 'ännere',
'unprotect'        => 'Widder freigewwe',
'newpage'          => 'Naie Said',
'talkpage'         => 'Iwwer die Said dischbediere',
'talkpagelinktext' => 'Dischbediere',
'personaltools'    => 'Perseenliche Werkzeische',
'talk'             => 'Dischbediere',
'views'            => 'Wievielmol aageguckt',
'toolbox'          => 'Werkzaich',
'otherlanguages'   => 'In annere Sproche',
'redirectedfrom'   => '(Wairrerglaidet vun $1)',
'redirectpagesub'  => 'Wairerlaidungssaid',
'lastmodifiedat'   => 'Die Said isch zum ledschde Mol gänneret woore am $1, am $2.',
'viewcount'        => 'Die Seid isch bis jetzerd {{PLURAL:$1|$1|$1}} mol uffgerufe worre.',
'jumpto'           => 'Spring zu:',
'jumptonavigation' => 'Navigation',
'jumptosearch'     => 'Suche',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Iwwer {{SITENAME}}',
'aboutpage'            => 'Project:Iwwer',
'copyright'            => 'Was do drin schdeht isch unner $1 verfiechbar.',
'copyrightpage'        => '{{ns:project}}:Urhewerrecht',
'currentevents'        => 'Was grad so bassiert isch',
'disclaimers'          => 'Hafdungsausschluß',
'disclaimerpage'       => 'Project:Impressum',
'edithelp'             => 'Hilf fer s Bearwaide',
'edithelppage'         => 'Help:Ännere',
'helppage'             => 'Help:Inhalt',
'mainpage'             => 'Hääptsaid',
'mainpage-description' => 'Startseid',
'portal'               => '{{SITENAME}}-Pordal',
'privacy'              => 'Dadeschutz',
'privacypage'          => 'Project:Daadeschutz',

'badaccess' => 'Kää ausraichende Recht',

'retrievedfrom'       => 'Vun "$1"',
'youhavenewmessages'  => 'Du hoscht $1 ($2).',
'newmessageslink'     => 'naie Nochrichte',
'newmessagesdifflink' => 'letschte Ännerung',
'editsection'         => 'bearwaide',
'editold'             => 'bearwaide',
'editlink'            => 'bearwaide',
'viewsourcelink'      => 'Quell aagucke',
'editsectionhint'     => 'Abschnitt ännere: $1',
'toc'                 => 'Inhald',
'showtoc'             => 'zaiche',
'hidetoc'             => 'versteggeln',
'site-rss-feed'       => '$1 RSS Feed',
'site-atom-feed'      => '$1 Atom Feed',
'page-rss-feed'       => '"$1" RSS Feed',
'page-atom-feed'      => '"$1" Atom Feed',
'red-link-title'      => '$1 (Said gebbt s nid)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Said',
'nstab-user'      => 'Benutzersaid',
'nstab-media'     => 'Media',
'nstab-special'   => 'Spezialsaid',
'nstab-project'   => 'Pordal',
'nstab-image'     => 'Datei',
'nstab-mediawiki' => 'Mitdeelung',
'nstab-template'  => 'Vorlaach',
'nstab-help'      => 'Hilfe',
'nstab-category'  => 'Kadegorie',

# General errors
'missing-article'    => 'De Text fer „$1“ $2 isch in de Datebank nit gfunne worre.

Normalerwais hääßt des, dass die Said glescht woore isch.

Wenn s des nit isch, hoscht villaicht en Fehler in de Datebank gfunne.
Bitte meld des an e [[Special:ListUsers/sysop|Adminischtrator]], un gebb d URL dezu aa.',
'missingarticle-rev' => '(Versionsnummer#: $1)',
'badtitletext'       => 'De Titel vun de aageforderte Said isch nid giltich, leer, odder e nid giltiche Link vun eme annere Wiki.
S kann sai, dass es ää odder meh Zaiche drin hot, wu im Titel vun de Said nid gebraucht werre därfe.',
'viewsource'         => 'Quelltekschd betrachde',

# Login and logout pages
'yourname'                => 'Benutzername:',
'yourpassword'            => 'Passwort:',
'remembermypassword'      => 'Mai Passwort uff dem Computer merke',
'login'                   => 'Omelde',
'nav-login-createaccount' => 'Aamelde / Benutzerkonto aaleche',
'userlogin'               => 'Omelde / Benutzerkonto anleche',
'logout'                  => 'Abmelde',
'userlogout'              => 'Abmelde',
'nologinlink'             => 'E Benutzerkonto aaleche',
'mailmypassword'          => 'Nais Passwort per E-Mail schicke',

# Edit page toolbar
'bold_sample'     => 'Fette Schrift',
'bold_tip'        => 'Fette Schrift',
'italic_sample'   => 'Kursive Schrift',
'italic_tip'      => 'Kursive Schrift',
'link_sample'     => 'Stichwort',
'link_tip'        => 'Interner Link',
'extlink_sample'  => 'http://www.example.com Linktext',
'extlink_tip'     => 'Externer Link (uff http:// Acht gewwe)',
'headline_sample' => 'Abschnitts-Iwwerschrift',
'headline_tip'    => 'Iwwerschrift Ewene 2',
'math_sample'     => 'Do Formel aigewwe',
'math_tip'        => 'Mathematische Formel (LaTeX)',
'nowiki_sample'   => 'Gebb do en Text ai, wu nit formatiert wird',
'nowiki_tip'      => 'Wiki-Formatierunge ignoriere',
'image_tip'       => 'Bildverwais',
'media_tip'       => 'Dateilink',
'sig_tip'         => 'Dai Unnerschrift mit ener Zaitaagab',
'hr_tip'          => 'Horizontale Linie (sparsam verwenne)',

# Edit pages
'summary'                          => 'Zammefassung:',
'subject'                          => 'Betreff:',
'minoredit'                        => 'Des ischt e klänni Bearwaidung',
'watchthis'                        => 'Die Said beowachde',
'savearticle'                      => 'Said schbeichere',
'preview'                          => 'Vorschau',
'showpreview'                      => 'Vorschau zaische',
'showlivepreview'                  => 'Live-Vorschau',
'showdiff'                         => 'Ännerunge zaische',
'anoneditwarning'                  => "'''Warnung:''' Du bischt nit aagemeldt. Dai IP-Adress werd in de Gschicht vun dem Artikel gspaichert.",
'summary-preview'                  => 'Zammefassung:',
'newarticle'                       => '(Nai)',
'newarticletext'                   => "Du bisch eme Link nogange zu re Said, wu s no gar nit gebbt.
Zum die Said aaleche, kannscht do in dem Käschtel unne aafange mid schraiwe (guck[[{{MediaWiki:Helppage}}|Hilfe]] fer meh Informatione).
Wenn do nid hin hoscht welle, no druck in Daim Browser uff '''Zrick'''.",
'noarticletext'                    => 'Uff derre Said gebbt\'s noch kää Text. Du kannscht uff annere Saide [[Special:Search/{{PAGENAME}}|den Aitrach suche]], <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} de Logbuchaidrach suche, wu dezu ghert],
orrer [{{fullurl:{{FULLPAGENAME}}|action=edit}} die Said bearwaide]</span>.',
'previewnote'                      => "'''Denk dran, dass des numme e Vorschau isch.'''
Dai Ännerunge sinn no nid gspaichert worre!",
'editing'                          => 'Am $1 bearwaide',
'editingsection'                   => '$1 bearwaide (Abschnitt)',
'copyrightwarning'                 => "Bitte gebb acht, dass alle Baidräch zu {{SITENAME}} unner $2 vereffentlicht werre (guck $1 fer mehr Details).
Wenn du nit willhsct, dass deswu du gschriwwe hoscht, gänneret un kopiert werre kann, dann duu s do nit naischraiwe.<br />
du gebbscht do au zu, dass Du des selwerscht gschriwwe hoscht orrer vun ere effentliche, fraie Quell ('''public domain''')orrer vun ere ähnliche fraie Quell her hoscht.
'''SCHRAIB DO NIX NAI, WAS URHEWERRECHTKLICH GSCHITZT ISCH!'''",
'templatesused'                    => '{{PLURAL:$1|Vorlach wu uff derre Said gebraucht werd|Vorlache wu uff derre Said gebraucht werre}}:',
'templatesusedpreview'             => '{{PLURAL:$1|Vorlach wu in derre Vorschau gebraucht werd|Vorlache wu in derre Vorschau gebraucht werre}}:',
'template-protected'               => '(gschitzt)',
'template-semiprotected'           => '(halb-gschitzt)',
'hiddencategories'                 => 'Die Said ghert zu {{PLURAL:$1|1 versteckelte Kategorie|$1 versteckelte Kategorie}}:',
'permissionserrorstext-withaction' => 'Du därfscht nid $2, aus {{PLURAL:$1|dem Grund|denne Grind}}:',
'moveddeleted-notice'              => 'Die Said isch glescht worre.
De Leschaidrach fer die Said isch do unne aagewwe als Quell.',

# History pages
'viewpagelogs'           => 'D Lochbiecher fer die Said aagucke',
'currentrev-asof'        => 'Aktuelle Version vun $1',
'revisionasof'           => 'Version vun $1',
'previousrevision'       => '← Ältere Versione',
'nextrevision'           => 'Naier Version →',
'currentrevisionlink'    => 'Aktuell Version',
'cur'                    => 'jetzert',
'next'                   => 'Negschte',
'last'                   => 'vorich',
'histlegend'             => "Du kannscht zwää Versione auswähle un verglaiche.<br />
Erklärung: '''({{int:cur}})''' = Unnerschied zu jetzert,
'''({{int:last}})''' = Unnerschied zu de voriche Version, '''{{int:minoreditletter}}''' = klenni Ännerung.",
'history-fieldset-title' => 'In de Versionsgschicht suche',
'histfirst'              => 'Ältschte',
'histlast'               => 'Naischte',

# Revision deletion
'rev-delundel'     => 'zaich/versteckel',
'revdelete-submit' => 'Uff die aussgewählt {{PLURAL:$1|Version|Versione}} owende',
'revdel-restore'   => 'Sichtbarkeit ännere',

# Merge log
'revertmerge' => 'Zammefiehrung rickgängich mache',

# Diffs
'history-title'           => 'Versionsgschicht vun "$1"',
'difference'              => '(Unnerschied zwische de Versione)',
'lineno'                  => 'Zail $1:',
'compareselectedversions' => 'Die Versione mitenonner vergleiche',
'editundo'                => 'zerick',

# Search results
'searchresults'             => 'Ergebnis suche',
'searchresults-title'       => 'Ergebnis suche fer "$1"',
'searchresulttext'          => 'Fer mehr Informatione iwwer d Such in {{SITENAME}}, guck emol uff [[{{MediaWiki:Helppage}}|{{int:help}}]].',
'searchsubtitle'            => 'Du hoscht no \'\'\'[[:$1]]\'\'\' gesucht ([[Special:Prefixindex/$1|alle Saide wo mit "$1" aafange]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|alle Saide wo uf "$1" verlinkt sin]])',
'searchsubtitleinvalid'     => "Du hoscht '''$1''' gsucht",
'notitlematches'            => 'Kää Saidetitel gfunne',
'notextmatches'             => 'Kää Iwwerainstimmunge mit Inhalde',
'prevn'                     => 'voriche {{PLURAL:$1|$1}}',
'nextn'                     => 'negschte {{PLURAL:$1|$1}}',
'viewprevnext'              => 'Gugg ($1 {{int:pipe-separator}} $2) ($3)',
'search-result-size'        => '$1 ({{PLURAL:$2|1 Word|$2 Wärder}})',
'search-redirect'           => '(Wairerlaitung $1)',
'search-section'            => '(Abschnitt $1)',
'search-suggest'            => 'Hoscht gemäänt: $1',
'search-interwiki-caption'  => 'Schweschterprojekt',
'search-interwiki-default'  => '$1 Ergebnis:',
'search-interwiki-more'     => '(meh)',
'search-mwsuggest-enabled'  => 'mid Vorschläch',
'search-mwsuggest-disabled' => 'kää Vorschläch',
'nonefound'                 => "'''Hiiwais:''' S werre standardmäßich numme e Dail Namensraim durchsucht. Setz ''all:'' vor Dai Suchbegriff zum alle Saide (mit Dischbediersaide, Voalaache usw.) durchsuche odder direkt de Name vum Namensraum, wu durchsucht werre sell.",
'powersearch'               => 'Erwaiterte Such',
'powersearch-legend'        => 'Erwaiterte Such',
'powersearch-ns'            => 'In de Namensraim suche:',
'powersearch-redir'         => 'Wairerlaitunge aazaiche',
'powersearch-field'         => 'Suche noch',
'powersearch-togglenone'    => 'Kään',

# Quickbar
'qbsettings-none' => 'Kään',

# Preferences page
'preferences'   => 'Optione',
'mypreferences' => 'Mai Aistellunge',
'saveprefs'     => 'Oischdellunge schbeichere',
'resetprefs'    => 'Oischdellunge verwerfe',
'guesstimezone' => 'Aus em Browser iwwernemme',

# Groups
'group'            => 'Grubb:',
'group-bot'        => 'Bots',
'group-sysop'      => 'Adminischdradore',
'group-bureaucrat' => 'Birokrade',
'group-all'        => '(alle)',

'group-bot-member'        => 'Bot',
'group-sysop-member'      => 'Adminischdrador',
'group-bureaucrat-member' => 'Birokrad',

'grouppage-sysop' => '{{ns:project}}:Adminischtratore',

# User rights log
'rightslog'  => 'Benutzerrecht-Logbuch',
'rightsnone' => '(-)',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'die Said bearwaide',

# Recent changes
'nchanges'                       => '$1 {{PLURAL:$1|Ännerung|Ännerunge}}',
'recentchanges'                  => 'Was zuletschd gemacht worre isch',
'recentchanges-legend'           => 'Optione vun de Aazaich',
'recentchanges-feed-description' => 'Di letschte Ännerunge vun {{SITENAME}} in des Feed aigewwe.',
'rcnote'                         => "Aagezaicht {{PLURAL:$1|werd '''1''' Ännerung|werre die letschte '''$1''' Ännerunge}} {{PLURAL:$2|vum letschte Dach|in de letschte '''$2''' Dache}} (Stand: $4, $5)",
'rclistfrom'                     => 'Zeich die letschte Ännerunge ab $1',
'rcshowhideminor'                => 'Klenne Ännerunge $1',
'rcshowhidebots'                 => 'Bots $1',
'rcshowhideliu'                  => 'Aagemeldte Benutzer $1',
'rcshowhideanons'                => 'Nit aagemeldte Benutzer $1',
'rcshowhidemine'                 => 'Mai Bearwaidunge $1',
'rclinks'                        => 'Zeich die letschte $1 Ännerunge in de letschte $2 Dache<br />$3',
'diff'                           => 'Unnerschied',
'hist'                           => 'Gschicht',
'hide'                           => 'versteggeln',
'show'                           => 'zaiche',
'minoreditletter'                => 'k',
'newpageletter'                  => 'N',
'boteditletter'                  => 'B',
'rc-enhanced-expand'             => "Details zaische (dodezu braucht's JavaScript)",
'rc-enhanced-hide'               => 'Details versteckeln',

# Recent changes linked
'recentchangeslinked'         => 'Was on verlinkde Saide gemacht worre isch',
'recentchangeslinked-feed'    => 'Was on verlinkde Seide gemacht worre isch',
'recentchangeslinked-toolbox' => 'Was on verlinkde Seide gemacht worre isch',
'recentchangeslinked-title'   => 'Ännerunge an Saide, wu „$1“ druf verlinkt',
'recentchangeslinked-summary' => "Des isch e Lischt vun Ännerunge, wu erscht gmacht worre sin an Saide, die wu vun ere bstimmte Said verlinkt sin (odder die wu zu ere bstimmte Kadegorie ghere).
Saide uff [[Special:Watchlist|Dainer Beowachdungslischt]] sin '''fett'''.",
'recentchangeslinked-page'    => 'Saide:',
'recentchangeslinked-to'      => 'Zaisch Ännerunge uff Saide, wu do her verlinkt sinn',

# Upload
'upload'        => 'Hochlade',
'uploadbtn'     => 'Datei hochlade',
'uploadlogpage' => 'Dateie-Logbuch',
'savefile'      => 'Datei schbeichere',
'uploadedimage' => 'hot „[[$1]]“ hochglade',

# File description page
'file-anchor-link'          => 'Datei',
'filehist'                  => 'Dateigschicht',
'filehist-help'             => 'Drick uff e Zaidpunkt zum aazääche, wie s dort ausgsähne hot.',
'filehist-current'          => 'aktuell',
'filehist-datetime'         => 'Zaidpunkt',
'filehist-thumb'            => 'Vorschaubild',
'filehist-thumbtext'        => 'Vorschaubild fer Version vum $1',
'filehist-user'             => 'Benutzer',
'filehist-dimensions'       => 'Moß',
'filehist-comment'          => 'Kommentar',
'imagelinks'                => 'Dateilinks',
'linkstoimage'              => 'Die {{PLURAL:$1|Said verwaist|$1 Saire verwaise}} uff die Datei:',
'sharedupload'              => 'Die Datei isch vun $1 un s kann sai, dass se ach vun annere Projekt gebraucht werd.',
'uploadnewversion-linktext' => 'E naiere Version vun derre Datei hochlade',

# File deletion
'filedelete-submit' => 'Lesche',

# Random page
'randompage' => 'Irnd en Adiggel',

# Statistics
'statistics' => 'Statischtike',

'brokenredirects-edit'   => 'bearwaide',
'brokenredirects-delete' => 'lesche',

# Miscellaneous special pages
'nbytes'        => '$1 {{PLURAL:$1|Byte|Bytes}}',
'nmembers'      => '$1 {{PLURAL:$1|Mitglied|Mitglieder}}',
'prefixindex'   => 'Alle Saide (mid Präfix)',
'newpages'      => 'Naie Saide',
'move'          => 'Verschiewe',
'movethispage'  => 'Die Said verschiewe',
'pager-newer-n' => '{{PLURAL:$1|negschte 1|negschte $1}}',
'pager-older-n' => '{{PLURAL:$1|vorich 1|voriche $1}}',

# Book sources
'booksources'               => 'Buchquelle',
'booksources-search-legend' => 'No Buchquelle suche',
'booksources-go'            => 'Geh',

# Special:Log
'log' => 'Logbiecher',

# Special:AllPages
'allpages'       => 'Alle Saide',
'alphaindexline' => 'vun $1 bis $2',
'prevpage'       => 'Voriche Said ($1)',
'allpagesfrom'   => 'Saide aazaische wu aafange mid:',
'allpagesto'     => 'Saide aazaische wu ufhere mid:',
'allarticles'    => 'Alle Saide',
'allpagesprev'   => 'Voriche',
'allpagesnext'   => 'Negschte',
'allpagessubmit' => 'Zaische',

# Special:LinkSearch
'linksearch' => 'Externe Links',

# Special:Log/newusers
'newuserlogpage'          => 'Naiaameldungs-Logbuch',
'newuserlog-create-entry' => 'Nais Benutzerkonto',

# Special:ListGroupRights
'listgrouprights-members' => '(Mitgliederlischt)',

# E-mail user
'emailuser' => 'E-Mail on den Benutzer',
'emailsend' => 'Abschigge',

# Watchlist
'watchlist'         => 'Beowachdungslischd',
'mywatchlist'       => 'Mai Beowachdungslischd',
'watchlistfor'      => "(fer '''$1''')",
'addedwatch'        => 'Zu de Beowachdungslischt zufieche',
'addedwatchtext'    => "Die Said \"[[:\$1]]\" isch zu Dainer [[Special:Watchlist|Beowachdungslischt]] zugefiecht worre.
Zukimftiche Ännerunge an derre Said un de Dischbediersaid, wu dezu ghert, werre doo aagezaicht, un d Said werd '''fett''' aagezaicht in de [[Special:RecentChanges|Letschte Ännerunge]] fer dass es ääfacher isch zum finne.",
'removedwatch'      => 'Aus de Beowachdungslischt rausgenumme',
'removedwatchtext'  => 'D Said "[[:$1]]" isch aus [[Special:Watchlist|Dainer Beowachdungslischt]] rausgenumme worre.',
'watch'             => 'Beowachde',
'watchthispage'     => 'Die Said beowachde',
'unwatch'           => 'Nimmi beowachde',
'watchlist-details' => 'S hot {{PLURAL:$1|$1 Said|$1 Saide}} uff Dainer Beowachdungslischt, Dischbediersaide zelle nid.',
'wlshowlast'        => 'Die letschte $1 Stunne $2 Dache $3 zaiche',
'watchlist-options' => 'Optione vun de Beowachdungslischt',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Beowachde ...',
'unwatching' => 'Nimmi beowachde ...',

'enotif_reset' => 'Alle Seide als bsuchd margiere',

# Delete
'deletepage'            => 'Said lesche',
'confirm'               => 'Bestädiche',
'delete-legend'         => 'Lesche',
'confirmdeletetext'     => 'Du bisch debai e Said z lesche mid alle Versione.
Bitte du bstätiche, dass Du des wllscht du, dass Du verstehsch, was des hääßt, un dass Du des machscht in Iwweraistimmung mit de [[{{MediaWiki:Policy-url}}|Richtline]].',
'actioncomplete'        => 'Aktion fertich',
'deletedtext'           => '"<nowiki>$1</nowiki>" isch gelescht worre.
Guck $2 fer e Lischt vun de letschte Leschunge.',
'deletedarticle'        => 'hot "[[$1]]" glescht',
'dellogpage'            => 'Leschlogbuch',
'deletecomment'         => 'Grund:',
'deleteotherreason'     => 'Annere/zusätzliche Grund:',
'deletereasonotherlist' => 'Annere Grund',

# Rollback
'rollbacklink' => 'Zericksetze',

# Protect
'protectlogpage'              => 'Saideschutz-Logbuch',
'protectedarticle'            => 'hot "[[$1]]" gschitzt',
'modifiedarticleprotection'   => 'hot de Schutzstatus vun "[[$1]]" gännert',
'protectcomment'              => 'Grund:',
'protectexpiry'               => 'Bis:',
'protect_expiry_invalid'      => 'Zaidraum isch nid gildich.',
'protect_expiry_old'          => 'Zaidraum licht in de Vergangehääd.',
'protect-text'                => "Du kannscht de Schutzstatus vun de Said '''<nowiki>$1</nowiki>''' aagucke un ännere.",
'protect-locked-access'       => "Dai Benutzerkonto hot ken Recht zum de Schutzstatus vun ener Said ze ännere.
Do hot s di aktuelle Aistellunge vun de Said '''$1''':",
'protect-cascadeon'           => 'Die Said isch gschitzt, wail se {{PLURAL:$1|zu derre Said ghert|zu denne Saide ghert}}, wu e Kaskadesperrung gelt.
Der Schutzstatus vun derre Said kannscht ännere, awwer des hot kää Aifluss uff d Kaskadesperrung.',
'protect-default'             => 'Alle Benutzer erlääwe',
'protect-fallback'            => '«$1»-Berechdichung nedich',
'protect-level-autoconfirmed' => 'Naie un nid aagemeldte Benutzer sperre',
'protect-level-sysop'         => 'Numme Adminischtratore',
'protect-summary-cascade'     => 'Kaskade',
'protect-expiring'            => 'bis $1 (UTC)',
'protect-cascade'             => 'Kaskadesperrung – alle aigebunnene Vorlache sinn midgsperrt.',
'protect-cantedit'            => 'Du kannscht de Schutzstatus vun derre Said nit ännere, wail Du nid d Berechdichung dezu hoscht.',
'restriction-type'            => 'Berechdichung:',
'restriction-level'           => 'Schutzewene:',

# Restrictions (nouns)
'restriction-edit' => 'Bearwaide',
'restriction-move' => 'Verschiewe',

# Undelete
'undelete'         => 'Widderherschdelle',
'undeletebtn'      => 'Widderherschdelle',
'undeletelink'     => 'aagucke/wirrer herstelle',
'undeletereset'    => 'Zuricksetze',
'undeletedarticle' => 'hot "[[$1]]" wirrer hergstellt',

# Namespace form on various pages
'namespace'      => 'Nomensraum',
'invert'         => 'Auswahl umkehre',
'blanknamespace' => '(Haaptsaid)',

# Contributions
'contributions'       => 'Was der gemacht hot',
'contributions-title' => 'Benutzerbaidräch vun $1',
'mycontris'           => 'Was du gemacht hoscht.',
'contribsub2'         => 'Fer $1 ($2)',
'uctop'               => '(aktuell)',
'month'               => 'un Monet (un frieher):',
'year'                => 'Ab em Johr (un frieher):',

'sp-contributions-newbies'  => 'Zaich numme Baidräch vun naie Benutzerkonte',
'sp-contributions-blocklog' => 'Sperrlogbuch',
'sp-contributions-talk'     => 'Dischbediere',
'sp-contributions-search'   => 'No Baidräch suche',
'sp-contributions-username' => 'IP-Adress orrer Benutzername:',
'sp-contributions-submit'   => 'Suche',

# What links here
'whatlinkshere'            => 'Was doher zeischt',
'whatlinkshere-title'      => 'Saide wu uff "$1" verlinke',
'whatlinkshere-page'       => 'Said:',
'linkshere'                => "Die Saide verlinke zu '''[[:$1]]''':",
'isredirect'               => 'Wairerlaitungsaid',
'istemplate'               => 'Vorlacheaibindung',
'isimage'                  => 'Bildlink',
'whatlinkshere-prev'       => '{{PLURAL:$1|vorich|voriche $1}}',
'whatlinkshere-next'       => '{{PLURAL:$1|negscht|negschte $1}}',
'whatlinkshere-links'      => '← Links',
'whatlinkshere-hideredirs' => '$1 Wairerlaitunge',
'whatlinkshere-hidetrans'  => '$1 Vorlacheaibindunge',
'whatlinkshere-hidelinks'  => '$1 Links',
'whatlinkshere-filters'    => 'Filter',

# Block/unblock
'blockip'                  => 'Benutzer bloggiere',
'ipbsubmit'                => 'Benutzer bloggiere',
'ipboptions'               => '2 Stunne:2 hours,1 Dach:1 day,3 Dache:3 days,1 Woch:1 week,2 Woche:2 weeks,1 Monet:1 month,3 Monet:3 months,6 Monet:6 months,1 Johr:1 year,Fer immer:infinite',
'ipusubmit'                => 'Die Adreß freigewwe',
'ipblocklist'              => 'Gsperrte IP-Adresse un Benutzername',
'blocklink'                => 'sperre',
'unblocklink'              => 'Sperr uffhewwe',
'change-blocklink'         => 'Sperr ännere',
'contribslink'             => 'Baidräch',
'blocklogpage'             => 'Sperrlogbuch',
'blocklogentry'            => 'hot [[$1]] gsperrt fer e Zaidraum vun $2 $3',
'unblocklogentry'          => 'hot d Sperr vun $1 uffghowwe',
'block-log-flags-nocreate' => 'Aaleche vun Benutzerkonte isch gsperrt',

# Developer tools
'lockbtn'   => 'Dadebonk schberre',
'unlockbtn' => 'Dadebonk freigewwe',

# Move page
'move-page-legend' => 'Said verschiewe',
'movepagetext'     => "Mid dem Format kannscht ener Said e naie Name gewwe, debai werre alle alde Versione uff de nai Name verschowe.
Aus em Alde Name werd e Wairerlaidungssaid´zum naie Name.
Wairerlaidungssaide, wu uff de ald Name umlaire, kannscht automatisch aktualisiere.
Wenn De des nid willsch, no guck uff [[Special:DoubleRedirects|doppelte]] orrer [[Special:BrokenRedirects|kaputte Wairerlaidunge]].
Du solltescht defer sorche, dass Links wairer zu de richdiche Saide fiehre.

Gebb Acht, dass die Said '''nid''' verschowe werd, wenn s scho e Said mid em naie Name hot, außer wenn se leer isch orrer e Wairerlaidung.
Des hääßt, Du kannscht ke Said, wu s schun gebbt, iwwerschraiwe.

'''WARNUNG!'''
Des isch e wichdiche Ännerung fer e Said un kann ziehmlich unerwartet sai fer wichdiche Saide;
bitte mach des numme, wenn Du die Folche vun derre Aktion kannsch abschätze.",
'movepagetalktext' => "D Dischbediersaid werd ach mid verschowe, '''ausser:'''
* Du verschiebsch die Saide in e annere Namensraum, odder
* s gebbt schun e Dischbediersaid mi dem Name, orrer
* Du wählsch unne d Option, se nid z verschiewe.

In denne Fäll misst mer d Dischbediersaid vun Hand kopiere.",
'movearticle'      => 'Said verschiewe:',
'newtitle'         => 'Zum naie Titel:',
'move-watch'       => 'Die Said beowachde',
'movepagebtn'      => 'Said verschiewe',
'pagemovedsub'     => 'Verschiewung hot geklappt',
'movepage-moved'   => '\'\'\'"$1" isch verschowe worre uff "$2"\'\'\'',
'articleexists'    => 'E Said mid dem Name gebbt s schun, orrer de Name, wu du gewählt hoscht, isch nid gildich.
Bitte nemm e annere Name.',
'talkexists'       => "'''Die Said selwerschd, isch verschowe worre, awwer d Dischbediersaid hot nid kenne verschowe werre, wail s schun enni gebbt mid dem Name.
Bitte duu se vun Hand zammefiehre.'''",
'movedto'          => 'verschowe uff',
'movetalk'         => 'Dischbediersaid, wu dezu ghert, verschiewe',
'1movedto2'        => 'hot [[$1]] uff [[$2]] verschowwe',
'1movedto2_redir'  => 'hot [[$1]] uff [[$2]] verschowe un debai e Wairerlaidung iwwerschriwwe',
'movelogpage'      => 'Verschiewungs-Logbuch',
'movereason'       => 'Grund:',
'revertmove'       => 'Zerick verschiewe',
'delete_and_move'  => 'Lesche un Verschiewe',

# Export
'export'        => 'Saide exportiere',
'export-submit' => 'Seide exbordiere',

# Thumbnails
'thumbnail-more' => 'Greßer mache',

# Special:Import
'import-interwiki-submit' => 'Impordiere',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Dai Benutzersaid',
'tooltip-pt-mytalk'               => 'Dai Dischbedier-Said',
'tooltip-pt-preferences'          => 'Dai Aistellunge',
'tooltip-pt-watchlist'            => 'D Lischt vun Saide, die wu du beowachde dusch',
'tooltip-pt-mycontris'            => 'Lischt vun Daine Baidräch',
'tooltip-pt-login'                => 'Du kannscht Dich aamelde, awwer du muscht s nit',
'tooltip-pt-logout'               => 'Abmelde',
'tooltip-ca-talk'                 => 'Iwwer d Inhaltssaid dischbediere',
'tooltip-ca-edit'                 => 'Du kannscht die Said bearwaide.
Bitte brauch de Vorschau-Knopp vor em Schbaichere',
'tooltip-ca-addsection'           => 'E naie Abschnitt aaleche',
'tooltip-ca-viewsource'           => 'Die Said isch gschitzt.
Du kannscht awwer de Quelltext aagucke',
'tooltip-ca-history'              => 'Ledschde Versione vun derre Said',
'tooltip-ca-protect'              => 'Die Said schitze',
'tooltip-ca-delete'               => 'Die Said lesche',
'tooltip-ca-move'                 => 'Die Said verschiewe',
'tooltip-ca-watch'                => 'Die Said zu Dainere Beowachdungslischt zufieche',
'tooltip-ca-unwatch'              => 'Die Said aus Dainer Beowachdunschlischde rausnemme',
'tooltip-search'                  => 'Durchsuch {{SITENAME}}',
'tooltip-search-go'               => 'Geh zu ere Said mit genää dem Namme, wenn s se gebbt',
'tooltip-search-fulltext'         => 'Such in de Said noch dem Text',
'tooltip-p-logo'                  => 'Haubdsaid',
'tooltip-n-mainpage'              => 'Uff d Hääptsaid geh',
'tooltip-n-mainpage-description'  => 'Haubdsaid aagucke',
'tooltip-n-portal'                => 'Iwwer s Projekt, was de duu kannscht, wo de ebbes finnscht',
'tooltip-n-currentevents'         => 'hinnergundsinformatione finne iwwer naie Eraichnis',
'tooltip-n-recentchanges'         => 'D Lischt vun de letschte Ännerunge in dem Wiki',
'tooltip-n-randompage'            => 'E zufälliche Said lade',
'tooltip-n-help'                  => 'De Ort zum rausfinne',
'tooltip-t-whatlinkshere'         => 'Lischt vun alle Wikisaide, wo do her verlinkt sin',
'tooltip-t-recentchangeslinked'   => 'Letschte Ännerunge in Saide, wu vun do verlinkt sin',
'tooltip-feed-rss'                => 'RSS feed fer die Said',
'tooltip-feed-atom'               => 'Atom feed fer die Said',
'tooltip-t-contributions'         => 'Die letschte Baidräch vun däm Benutzer aagucke',
'tooltip-t-emailuser'             => 'Dem Benutzer e E-Mail schicke',
'tooltip-t-upload'                => 'Dateie nuflade',
'tooltip-t-specialpages'          => 'Lischt vun alle Spezialsaide',
'tooltip-t-print'                 => 'Druckversion vun derre Said',
'tooltip-t-permalink'             => 'E dauerhafte Link zu derre Version vun de Said',
'tooltip-ca-nstab-main'           => 'D Inhaldssaid aagucke',
'tooltip-ca-nstab-user'           => 'D Benutzersaid aagucke',
'tooltip-ca-nstab-special'        => 'Des isch e Spezialsaid, du kannscht d Said sälwerscht nit ännere',
'tooltip-ca-nstab-project'        => 'D Projektsaid aagucke',
'tooltip-ca-nstab-image'          => 'D Dateisaid aaugucke',
'tooltip-ca-nstab-template'       => 'Vorlach aagucke',
'tooltip-ca-nstab-category'       => 'D Kategoriesaid aagucke',
'tooltip-minoredit'               => 'Des als klenne Ännerung markiere',
'tooltip-save'                    => 'Dai Ännerunge spaichere',
'tooltip-preview'                 => 'Guck Daine Ännerunge in de Vorschau aa, vor Du uff Spaichere driksch!',
'tooltip-diff'                    => 'Guck, welle Ännerunge Du im Text gmacht hoscht',
'tooltip-compareselectedversions' => 'D Unnerschied zwische denne zwai ausgwehlte Versione aagucke',
'tooltip-watch'                   => 'Die Said zu Dainer Beowachdunglischd zufieche',
'tooltip-rollback'                => '„Zericksetze“ maxcht alle Bearwaidunge vum letschte Bearwaider rickgängich',
'tooltip-undo'                    => '„Zerick“ macht numme die Ännerung rickgängich un zaicht d Vorschau aa.
Du kannscht e Grund in dr Zammfassung aagewwe',

# Browsing diffs
'previousdiff' => '← Ältere Bearwaidung',
'nextdiff'     => 'Naiere Bearwaidung →',

# Media information
'file-info-size'       => '($1 × $2 Pixels, Dateigreß: $3, MIME-Type: $4)',
'file-nohires'         => '<small>Ke hechere Ufflesung verfiechbar.</small>',
'svg-long-desc'        => '(SVG-Datei, Basisgreß $1 × $2 Pixels, Dateigreß: $3)',
'show-big-image'       => 'Gsamte Ergebnis',
'show-big-image-thumb' => '<small>Greß vun derre Vorschau: $1 × $2 Pixels</small>',

# Special:NewFiles
'showhidebots' => '(Bots $1)',
'ilsubmit'     => 'Such',

# Bad image list
'bad_image_list' => 'Format:

nur Zaile, die wu mit eme * aafange werre bericksichticht.
De erscht Link muss e Link zu ere unerwinschte Datei sai.
Annere Links in der glaiche Zail werre als Ausnahme behannelt, d. h. Saide, wu d Datei drin vorkumme därft.',

# Metadata
'metadata'          => 'Metadata',
'metadata-help'     => 'Die Datei hot waitere Informatione, wahrschainlich vun de Digitalkamera oder vum Scanner, mit dem wu sie gmacht worre sinn.
Wenn die Datei verännert worre isch, dann kann s sai, dass die zusätzlich Information fer die verännert Datei nimmi richtich isch.',
'metadata-expand'   => 'Erwaiterte Details aazaiche',
'metadata-collapse' => 'Erwaiterte Details versteckeln',
'metadata-fields'   => 'Die EXIF-Metadate werre in de Bild-Bschraiwung ach aagezeicht, wenn d Metadate-Tabelle versteckelt isch.
Annere Metadate sinn standardmäßig versteckelt.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength',

'exif-gaincontrol-0' => 'Kään',

# External editor support
'edit-externally'      => 'Die Datei bearwaide mit ener externe Aawendung',
'edit-externally-help' => '(Guck uff [http://www.mediawiki.org/wiki/Manual:External_editors Installationsaawisige] fer meh Informatione)',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'alle',
'imagelistall'     => 'alle',
'watchlistall2'    => 'alle',
'namespacesall'    => 'alle',
'monthsall'        => 'alle',

# Watchlist editing tools
'watchlisttools-view' => 'Die wichdiche Ännerunge aagucke',
'watchlisttools-edit' => 'D Beowachdunglischt aagucke un bearwaide',
'watchlisttools-raw'  => 'ime große Textfeld bearwaide',

# Special:SpecialPages
'specialpages' => 'Spezialsaide',

# Special:Tags
'tags-edit' => 'bearwaide',

);
